@@ -24,48 +24,38 @@
 #include <QMenu>
 #include <QMenuBar>
 #include <QAction>
+#include <QApplication>
 #include <QLayoutItem>
 
+
 ActionConfigWidget::ActionConfigWidget(QWidget* parent) : QWidget(parent)
 {
     m_gridLayout = new QGridLayout(this);
-    /*
-    QLabel* l = new QLabel( this );
-    l->setText( "Hello World!" );
+    setLayout(m_gridLayout);
+
+    // FIXME: pixelSize() returns an useful -1 here, pointSize() doesn't
+    // that's correct though, since points != pixels, and the latter matter
+    m_gridLayout->setVerticalSpacing(QApplication::font().pointSize() / 2);
 
-    m_gridLayout->addWidget(l, 0, 0);
-    */
 }
 
 ActionConfigWidget::~ActionConfigWidget()
 {}
 
-
 void ActionConfigWidget::addWidgets(QList<QPair<QString, QWidget*> > configMap)
 {
     int row = m_gridLayout->rowCount();
     row++;
 
     QCheckBox* currentSectionCheckbox = 0;
-    /*
-        //Clean the values
-        QList<QString>::const_iterator it;
-        for (it = list.constBegin(); it != list.constEnd(); ++it) {
-            QString tempString = *it;
-            tempString = tempString.trimmed();
-            tempString = tempString.mid(1, tempString.length()-2);
-            versionList.append(tempString);
-        }
-    */
+
     QList<QPair<QString, QWidget*> >::const_iterator it;
     for (it = configMap.constBegin(); it != configMap.constEnd(); ++it) {
-    //foreach (QPair<QString, QWidget*> line, configMap) {
         QPair<QString, QWidget*> line = *it;
         if (line.first.isEmpty()) {
             // A title checkbox
             currentSectionCheckbox = qobject_cast<QCheckBox*>(line.second);
             currentSectionCheckbox->setChecked(true);
-            currentSectionCheckbox->setStyleSheet("font-weight: bold;");
             m_gridLayout->addWidget(line.second, row, 0, 1, 3);
         } else {
             // connect enabled / disabled
@@ -76,10 +66,10 @@ void ActionConfigWidget::addWidgets(QList<QPair<QString, QWidget*> > configMap)
             m_gridLayout->addWidget(label, row, 1, Qt::AlignRight);
             m_gridLayout->addWidget(line.second, row, 2);
 
-            connect(currentSectionCheckbox, SIGNAL(toggled(bool)),
-                    label, SLOT(setEnabled(bool)));
-            connect(currentSectionCheckbox, SIGNAL(toggled(bool)),
-                    line.second, SLOT(setEnabled(bool)));
+            connect(currentSectionCheckbox, &QAbstractButton::toggled,
+                    label, &QWidget::setEnabled);
+            connect(currentSectionCheckbox, &QAbstractButton::toggled,
+                    line.second, &QWidget::setEnabled);
         }
         row++;
     }
